@@ -94,10 +94,7 @@ getPlot <- function(pm, i, j){
       stop(str_c("unknown plot object type.\n", firstNote, strObj))
     }
 
-    if (!is.null(pm$gg)) {
-      # adding custom gg
-      p <- p + pm$gg
-    }
+    p <- add_gg_info(p, pm$gg)
   }
 
   p
@@ -105,14 +102,25 @@ getPlot <- function(pm, i, j){
 
 
 get_pos <- function(pm, i, j) {
-  if (!identical(pm$byrow, TRUE)) {
-    pos <- i + (pm$nrow * (j - 1))
-  } else {
+  if (isTRUE(pm$byrow)) {
     pos <- j + (pm$ncol * (i - 1))
+  } else {
+    pos <- i + (pm$nrow * (j - 1))
   }
   pos
 }
 
+get_pos_rev <- function(pm, pos) {
+  if (isTRUE(pm$byrow)) {
+    i <- ceiling(pos / pm$ncol)
+    j <- (pos - 1) %% pm$ncol + 1
+  } else {
+    i <- (pos - 1) %% pm$nrow + 1
+    j <- ceiling(pos / pm$nrow)
+  }
+  c(i, j)
+}
+
 
 check_i_j <- function(pm, i, j) {
   if ( (length(i) > 1) || (mode(i) != "numeric")) {
